@@ -58,10 +58,14 @@ get_microdata <- function(year = 2018,
 
 
   if (is.null(destfile) | !destfile_exists) {
-    attempt::stop_if_not(
-      .x = curl::has_internet(),
-      msg = "No se detecto acceso a internet. Por favor checkea tu conexion."
-    )
+    # attempt::stop_if_not(
+    #   .x = curl::has_internet(),
+    #   msg = "No se detecto acceso a internet. Por favor checkea tu conexion."
+    # )
+    if (!curl::has_internet()) { # network is down = message (not an error anymore)
+      message("No se detecto acceso a internet. Por favor checkea tu conexion.")
+      return(NULL)
+    }
 
     df <- tibble::as_tibble(expand.grid(
       year = year,
